<h2 align="center">RESP : Research Papers Search </h2>
<h4 align="center"> Fetch Academic Research Papers from different sources including Google Scholar, ACL, ACM, PMLR etc based on keywords or title </h3>

[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![GitHub commit](https://img.shields.io/github/last-commit/monk1337/resp)](https://github.com/monk1337/resp/commits/main)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![Open All Collab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/188cWcZrBRVGAF3Dp_5uswmLgbBNKSioB?usp=sharing)



### 🎮 Features

- Fetch all citations of a single paper from Google Scholar
- Fetch all related papers of a single paper from Google Scholar
- Fetch all connected papers from connectedpapers.com (it doesn't use a citation tree, it uses [similarity](https://www.connectedpapers.com/about) to build graphs)
- Fetch relevant papers based on keywords from different sources including ACL, ACM, PMLR etc



## 🤖 Setup

```shell
git clone https://github.com/monk1337/resp
cd resp 
pip install -r requirements.txt && pip install -e .
```






### Fetching Papers from :

| Conference Name |  |
|-------------|-------|
| [Google Scholar](https://scholar.google.com/) | ✅    |
| [Acl](https://aclanthology.org/) | ✅    |
| [Pmlr](https://proceedings.mlr.press/) | ✅    |
| [Arxiv](https://arxiv.org/) | ✅    |
| [Semantic Scholar](https://www.semanticscholar.org/) | ✅    |
| [NeurIPS](https://nips.cc/) | ✅    |
| [IJCAI](https://www.ijcai.org/) | ✅    |
| [openreview](https://openreview.net/) | ✅    |
| [thecvf](https://openaccess.thecvf.com/menu) | ✅    |


If you find this repository useful, please cite our project:

```

@misc{Resp2021,
  title = {RESP : Research Papers Search},
  author = {Pal, Ankit},
  year = {2021},
  howpublished = {\url{https://github.com/monk1337/resp}},
  note = {Fetch Academic Research Papers from different sources including Google Scholar, ACL, ACM, PMLR etc based on keywords or title}
}

```


I'm constantly working on new projects, and I'm excited to continue adding to my collection. If you'd like to support my work and help fuel my passion, consider buying me a coffee :)

<p align="center">
<br>
<a href="https://www.buymeacoffee.com/stoicbatman"><img src="https://github.com/appcraftstudio/buymeacoffee/raw/master/Images/snapshot-bmc-button.png" width="300"></a>
</p>

[![Star History Chart](https://api.star-history.com/svg?repos=monk1337/resp&type=Date)](https://star-history.com/#monk1337/resp&Date)

